=========
Utilities
=========

.. automodule:: sigmaepsilon.mesh.utils.space
    :members:

.. automodule:: sigmaepsilon.mesh.utils.topology.topo
    :members:

.. automodule:: sigmaepsilon.mesh.utils.topology.tr
    :members:

.. automodule:: sigmaepsilon.mesh.utils.tri
    :members:

.. automodule:: sigmaepsilon.mesh.utils.tet
    :members:

.. automodule:: sigmaepsilon.mesh.utils.knn
    :members:

.. automodule:: sigmaepsilon.mesh.utils.utils
    :members: